#
# spec file for package netavark
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netavark
Version:        1.7.0
Release:        2.1
Summary:        Container network stack
License:        Apache-2.0
URL:            https://github.com/containers/%{name}
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  go-md2man
BuildRequires:  protobuf-devel
BuildRequires:  rust+cargo >= 1.66
BuildRequires:  systemd-rpm-macros
# aardvark-dns and %%{name} are usually released in sync
Requires:       aardvark-dns >= %{version}
# Provides: container-network-stack = 2

%description
Netavark is a rust based network stack for containers. It is being
designed to work with Podman but is also applicable for other OCI
container management applications.
Netavark is a tool for configuring networking for Linux containers.
Its features include:
* Configuration of container networks via JSON configuration file
* Creation and management of required network interfaces,
    including MACVLAN networks
* All required firewall configuration to perform NAT and port
    forwarding as required for containers
* Support for iptables and firewalld at present, with support
    for nftables planned in a future release
* Support for rootless containers
* Support for IPv4 and IPv6
* Support for container DNS resolution via aardvark-dns.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
cargo build --release
mkdir -p bin
cp target/release/%{name} bin/

cd docs
go-md2man -in %{name}.1.md -out %{name}.1

%install
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}

%files
%license LICENSE
%dir %{_libexecdir}/podman
%{_libexecdir}/podman/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_unitdir}/%{name}-dhcp-proxy.service
%{_unitdir}/%{name}-dhcp-proxy.socket

%pre
%service_add_pre %{name}-dhcp-proxy.service %{name}-dhcp-proxy.socket

%post
%service_add_post %{name}-dhcp-proxy.service %{name}-dhcp-proxy.socket

%preun
%service_del_preun %{name}-dhcp-proxy.service %{name}-dhcp-proxy.socket

%postun
%service_del_postun %{name}-dhcp-proxy.service %{name}-dhcp-proxy.socket

%changelog
* Tue Jul 11 2023 Danish Prakash <danish.prakash@suse.com>
- Disable restricting builds only for tier1 platforms
  i.e. only for x86_64 and aarch64 and enable for all.
* Mon Jul  3 2023 danish.prakash@suse.com
- Update to version 1.7.0:
  * release v1.7.0
  * Update release notes for v1.7.0
  * fix(deps): update rust crate tokio to 1.29
  * netavark: make --config required for dns
  * fix(deps): update rust crate serde_json to 1.0.99
  * fix(deps): update rust crate clap to 4.3.8
  * [CI:BUILD] Packit: add Fedora downstream tasks
  * run cargo update
  * fix(deps): update rust crate serde_json to 1.0.97
  * fix(deps): update rust crate sha2 to 0.10.7
  * fix(deps): update rust crate clap to 4.3.4
  * chore(deps): update dependency containers/automation_images to v20230614
  * fix(deps): update rust crate clap to 4.3.3
  * fix(deps): update rust crate log to 0.4.19
  * aardvark: fix missleading dns disabled log
  * firewall: add NETAVARK_ISOLATION_3 chain for strict isolation
  * docs: fix link to getting started
  * fix(deps): update rust crate serde to 1.0.164
  * netlink: fix incorrect info log for del_route
  * dhcp-proxy: apply new ip address/gateway
  * test-dhcp: fix broekn has_ip() check
  * dhcp-proxy: actually implement renewing leases
  * dhcp-proxy: simplify code
  * dhcp-proxy: drop macaddr dependency
  * dhcp-proxy: remove some unused traits
  * fix(deps): update rust crate zbus to 3.13.1
  * fix(deps): update rust crate clap to 4.3.2
  * chore(deps): update rust crate once_cell to 1.18.0
  * fix(deps): update rust crate url to 2.4.0
  * fix(deps): update rust crate clap to 4.3.1
  * chore(deps): update dependency containers/automation_images to v20230601
  * chore(deps): update rust crate chrono to 0.4.26
  * chore(deps): update rust crate chrono to 0.4.25
  * fix(deps): update rust crate log to 0.4.18
  * chore(deps): update rust crate once_cell to 1.17.2
  * macvlan: add bclim option
  * parse_option(): return option instead of default
  * add no_default_gateway option
  * fix(deps): update rust crate clap to 4.3.0
  * chore(deps): update dependency containers/automation_images to v20230517
  * fix(deps): update rust crate serde to 1.0.163
  * Add ability to add static route
  * fix(deps): update rust crate serde to 1.0.162
  * Cirrus: Update fedora name to match image
  * fix(deps): update rust crate clap to 4.2.7
  * chore(deps): update dependency containers/automation_images to v20230426
  * correct typo in Makefile
  * simplify path printing
  * fix(deps): update rust crate tokio to 1.28
  * aardvark-dns pid: return better errors
  * fix comment in Subnet definition
  * aardvark: no error when aardvark config is not there
  * fix(deps): update rust crate zbus to 3.12.0
  * fix(deps): update rust crate clap to 4.2.4
  * fix(deps): update rust crate clap to 4.2.2
  * fix(deps): update rust crate serde_json to 1.0.96
  * update clap to v4
  * fix(deps): update rust crate serde to 1.0.160
  * bump to v1.7.0-dev
* Fri Jun 23 2023 Danish Prakash <danish.prakash@suse.com>
- Add aardvark-dns as Requires for netavark
* Wed Apr 12 2023 danish.prakash@suse.com
- Update to version 1.6.0:
  * v1.6.0 release
  * Update release notes for v1.6.0
  * dhcp-proxy: fix typo for --activity-timeout
  * chore(deps): update dependency containers/automation_images to v20230405
  * dhcp-proxy: use better error when connection fails
  * add documentation for netavark plugins
  * add stderr example plugin to test stderr passthrough
  * add netavark plugin driver
  * add example error plugin
  * add host-device example plugin
  * plugin: add simple plugin interface
  * netlink: add dump_addresses
  * netlink: add set_link_ns
  * dhcp-proxy: correctly exit > 0 on errors
  * fix(deps): update rust crate tonic to 0.9
  * fix(deps): update rust crate mozim to 0.2.2
  * fix(deps): update rust crate serde to 1.0.159
  * fix(deps): update rust crate netlink-sys to 0.8.5
  * dhcp-proxy: create socket directory only when used
  * dhcp-proxy: do not remove socket when running under systemd
  * Makefile: netavark-dhcp-proxy.service use correct path
  * fix(deps): update rust crate http to 0.2.9
  * chore(deps): update rust crate once_cell to 1.17.1
  * fix(deps): update rust-futures monorepo to 0.3.28
  * fix(deps): update rust crate serde_json to 1.0.95
  * chore(deps): update dependency containers/automation_images to v20230330
  * Disable Dependabot in favor of Renovate
  * chore(deps): update rust crate chrono to 0.4.24
  * build(deps): bump ipnet from 2.7.1 to 2.7.2
  * build(deps): bump serde from 1.0.158 to 1.0.159
  * build(deps): bump serde_json from 1.0.94 to 1.0.95
  * update,main: dont write empty space when no network_dns_servers is given
  * fix(deps): update rust crate tokio to 1.27
  * Quit Leasing when Client disconnects
  * build(deps): bump mozim from 0.2.1 to 0.2.2
  * iptables: fix incorrect debug statement
  * build(deps): bump serde from 1.0.156 to 1.0.158
  * iptables: port fw handle wildcard address correctly
  * chore(deps): update dependency containers/automation_images to v20230320
  * build(deps): bump zbus from 3.11.0 to 3.11.1
  * build(deps): bump anyhow from 1.0.69 to 1.0.70
  * [CI:BUILD] Packit: trigger builds on commit to main branch
  * Cirrus: Invalidate v2 bin cache
  * Include Systemd Files in RPM Package
  * Cirrus: Fix success failing on artifact extraction
  * fix lint issue with new rust version 1.68
  * Cirrus: Update to newer CI VM images
  * build(deps): bump serde from 1.0.152 to 1.0.156
  * combine dhcp-proxy and netavark into one binary
  * update: should allow empty network_dns_servers
  * build(deps): bump libc from 0.2.139 to 0.2.140
  * fix aarch64 ncat flake
  * update to mozim 0.2.1
  * build(deps): bump zbus from 3.10.0 to 3.11.0
  * packit: Update build release tag correctly
  * test: move proto option into run_nc_test()
  * test: add netns pid param to port checks
  * test: import podman code to check for ports
  * cirrus.yaml: add new binaries in art_prep_script
  * fix netavark-dhcp-proxy binary in system unit
  * import netavark-proxy-dhcp tests
  * add build_proxy_client target
  * add netavark-dhcp-proxy to rpm
  * Fix dhcp-proxy build
  * Merge nv-dhcp-proxy into nv
  * fix default route metric test name
  * build(deps): bump tokio from 1.25.0 to 1.26.0
  * Support none parameter on NETAVARK_FW
  * build(deps): bump anyhow from 1.0.68 to 1.0.69
  * Fix typos
  * update netlink-packet-{route,core} to 0.15 and 0.5
  * build(deps): bump serde_json from 1.0.92 to 1.0.93
  * build(deps): bump zbus from 3.8.0 to 3.10.0
  * [CI:BUILD] Packit: initial enablement
  * Allow custom cargo binary path
  * build(deps): bump serde_json from 1.0.91 to 1.0.92
  * Cirrus: Reduce requested CPUs for compile-tasks
  * bump to version 1.0.6-dev
  * build(deps): bump netlink-sys from 0.8.3 to 0.8.4
  * Add renovate.json5
* Thu Mar 16 2023 Dan Čermák <dcermak@suse.com>
- Bump required rust version & fix libexecdir
* Fri Feb 10 2023 Dan Čermák <dcermak@suse.com>
- First version of netavark
